/*****************************************************************************
 * FILE NAME: vautil.h                                                       *
 *                                                                           *
 * DESCRIPTION:                                                              *
 *    Contains definitions required to obtain key values from the registry   *
 *    or environment space.  Note: Key values are case sensitive on OS2.     *
 *                                                                           *
 * COPYRIGHT:                                                                *
 *   (C) Copyright International Business Machines Corporation 1997          *
 *   Licensed Material - Property of IBM - All Rights Reserved.              *
 *   US Government Users Restricted Rights - Use, duplication, or disclosure *
 *   restricted by GSA ADP Schedule Contract with IBM Corp.                  *
 *                                                                           *
 *****************************************************************************
 * UPDATES:                                                                  *
 * 11/16/97 - Jose Vargas - Updated file for used by IBM Visualage Cobol and *
 * JV0001                   PL/I products.                                   *
 *****************************************************************************/

#ifndef _VAUTIL_H_
#define _VAUTIL_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Name:          readenv
 * Description:   Returns the string value associated with an environment
 *                variable belonging to a specified component.
 *                This call returns the string associated with the
 *                environment variable name via getenv().  If getenv()
 *                indicates that the variable is not set, then the
 *                product registry is searched for a key name matching
 *                the component name is searched.  If a value is stored
 *                in the key matching the environment variable is found,
 *                a string value is returned.  The function will search
 *                the user space for the key and then the system space.
 * Return:        A static buffer containing the string value associated
 *                with the environment variable (Do not free storage).
 *                NULL is returned if environment variable is not set.
 * Parameters:    Environment variable name.
 *                Component name within the product registry.
 *                (A NULL component name is accepted to indicate a generic
 *                product level variable possibly used by multiple components).
 * Exceptions:    None
 */
char *readenv(char *envname, char *compname);

/**
 * Name:          writeenv
 * Description:   This method writes a string value to an environment variable
 *                name for a specified component.  This environment name is
 *                not set to this value for other processes running in the
 *                system.
 * Return:        The length of the string.
 * Parameters:    A Character String containing the environment variable name
 *                and the string value to set in the following form:
 *                "envname=EnvironmentString"
 *                Component name within the product registry.
 * Exceptions:    None
 */
int   writeenv(char *String, char *compName);

/**
 * Name:          readIntValue
 * Description:   Returns the long integer value associated with a product
 *                variable belonging to a specified component.
 *                The environment variable name corresponds to a key value
 *                name inside the product registry within the component
 *                specified.  The function will search
 *                the user space for the key and then the system space.
 * Return:        Zero if value is found in the registry.
 *                -1 is returned if product variable is not set.
 * Parameters:    Product variable name.
 *                Component name within the product registry.
 *                Integer buffer to return integer.
 * Exceptions:    None
 */
int readIntValue(char *envName, char *compName, int *retValue);

/**
 * Name:          writeIntValue
 * Description:   This method writes an integer value to a product variable
 *                name for a specified component in the product registry for
 *                the current user.  The environment variable IS SET FOR ALL
 *                processes running on the system for the current user (NT).
 *                This call will replace the value stored in the environment
 *                variable in the registry ore creates the key.
 * Return:        Zero if product variable is set to the value
 *                -1 is returned if product variable cannot be set.
 * Parameters:    Product variable name.
 *                Component name within the product registry.
 *                Integer value to set environment name to.
 * Exceptions:    None
 */
int   writeIntValue(char *envName, char *compName, int intValue);

/**
 * Name:          readStringValue
 * Description:   Returns the String value associated with a product
 *                variable belonging to a specified component.
 *                The product variable name corresponds to a key value
 *                name inside the product registry within the component
 *                specified.  The function will search
 *                the user space for the key and then the system space.
 * Return:        Zero if a value is returned.
 *                -1 is returned if no value is returned.
 * Parameters:    Product variable name.
 *                Component name within the product registry.
 *                Character String buffer for return string.
 *                Return parameter for the length - set initially to the size
 *                of the buffer parameter.
 * Exceptions:    None
 */
int readStringValue(char *envName, char *compName, char *retValue, int *retLength);


/**
 * Name:          writeStringValue
 * Description:   This method writes a string value to a product variable
 *                name for a specified component in the product registry of
 *                the current user.  The product variable IS SET FOR ALL
 *                processes running on the system for the current user (NT).
 *                This call will replace the value stored in the product
 *                variable or create the key in the registry/.ini if it does
 *                not exist.
 * Return:        Zero if product variable is set to the value.
 *                -1 is returned if product variable cannot be set.
 * Parameters:    Product variable name.
 *                Component name within the product registry.
 *                String to set environment name to (NULL Terminated).
 * Exceptions:    None
 */
int   writeStringValue(char *envName, char *compName, char *stringValue);


/**
 * Name:          deleteEnvValue
 * Description:   This method removes a product variable for a given component.
 *                This call will remove the entry in the product registry.
 * Return:        Zero if the product variable value was removed.
 *                -1 is returned if the product variable could not be removed.
 * Parameters:    Product variable name.
 *                Component name within the product registry.
 * Exceptions:    None
 */
int   deleteEnvValue(char *envName, char *compName);

/**
 * Name:          deleteEnvComponent
 * Description:   This method removes all product variables for a given component.
 *                This call will remove the compnent key in the product registry.
 * Return:        Zero if the component was removed.
 *                -1 is returned if the component could not be removed.
 * Parameters:    Component name within the product registry.
 * Exceptions:    None
 */
int   deleteEnvComponent(char *compName);


#ifdef __cplusplus
}
#endif

// #if defined(__TOS_OS2__) || defined(__TOS_WIN__)
// #ifndef __NO_DEFAULT_LIBS__
//   #pragma library("CPPBPG40.LIB")
// #endif
// #endif

#endif

